@@ -1051,6 +1051,7 @@ ev_application_startup (GApplication *gapplication)
           "win.open-copy",              "<Ctrl>N", NULL,
           "win.save-copy",              "<Ctrl>S", NULL,
           "win.print",                  "<Ctrl>P", NULL,
+          "win.show-properties",        "<alt>Return", NULL,
           "win.copy",                   "<Ctrl>C", "<Ctrl>Insert", NULL,
           "win.select-all",             "<Ctrl>A", NULL,
           "win.save-settings",          "<Ctrl>T", NULL,
@@ -1061,7 +1062,7 @@ ev_application_startup (GApplication *gapplication)
           "win.find-next",              "<Ctrl>G", NULL,
           "win.find-previous",          "<Ctrl><Shift>G", NULL,
           "win.select-page",            "<Ctrl>L", NULL,
-          "win.go-backward",            "<Shift>Page_Up", NULL,
+          "win.go-backwards",           "<Shift>Page_Up", NULL,
           "win.go-forward",             "<Shift>Page_Down", NULL,
           "win.go-next-page",           "n", NULL,
           "win.go-previous-page",       "p", NULL,
@@ -1071,7 +1072,7 @@ ev_application_startup (GApplication *gapplication)
           "win.sizing-mode::fit-width", "w", NULL,
           "win.open-menu",              "F10", NULL,
           "win.caret-navigation",       "F7", NULL,
-          "win.zoom-in",                "plus", "<Ctrl>plus", "KP_Add", "<Ctrl>KP_Add", NULL,
+          "win.zoom-in",                "plus", "<Ctrl>plus", "KP_Add", "<Ctrl>KP_Add", "equal", "<Ctrl>equal", NULL,
           "win.zoom-out",               "minus", "<Ctrl>minus", "KP_Subtract", "<Ctrl>KP_Subtract", NULL,
           "win.show-side-pane",         "F9", NULL,
           "win.fullscreen",             "F11", NULL,
